@@ -104,6 +104,8 @@ class SchemaMeta(type):
         # Set klass.opts in __new__ rather than __init__ so that it is accessible in
         # get_declared_fields
         klass.opts = klass.OPTIONS_CLASS(meta)
+        # Pass the inherited `ordered` into opts
+        klass.opts.ordered = ordered
         # Add fields specifid in the `include` class Meta option
         cls_fields += list(klass.opts.include.items())
 
